@@ -6,10 +6,11 @@ fi
 
 ./configure \
     --prefix=$PREFIX \
-    --without-readline \
+    --with-readline \
     --with-libraries=$PREFIX/lib \
     --with-includes=$PREFIX/include \
-    --with-openssl
+    --with-openssl \
+    --with-gssapi
 
 make
 # make check # Failing with 'initdb: cannot be run as root'.
